==> haskell-ral-0.2.2-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ral.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ral
version:              0.2.2
visibility:           public
id:                   ral-0.2.2-GSSJQlEMbHIGAa9DjBMF29
key:                  ral-0.2.2-GSSJQlEMbHIGAa9DjBMF29
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Random access lists
description:
    This package provides ordinary random access list, '\''RAList'\'', and also
    a length indexed variant, '\''RAVec'\''.

    The data structure allows fast cons-operation (like ordinary list) but also fast random access (like non-functional arrays).

    For @lens@ or @optics@ support see [ral-lens](https://hackage.haskell.org/package/ral-lens) and [ral-optics](https://hackage.haskell.org/package/ral-optics) packages respectively.

    === Similar packages

    These packages don'\''t provide length-indexed variants, and their '\''RAList'\'' has
    opaque structure.

    * https://hackage.haskell.org/package/ralist
    * https://hackage.haskell.org/package/random-access-list

category:             Data, Dependent Types, Singletons
abi:                  c495caf456b9c9f8bedbbdafbd261296
exposed:              True
exposed-modules:
    Data.RAList Data.RAList.NonEmpty Data.RAList.Tree Data.RAVec
    Data.RAVec.NonEmpty Data.RAVec.Tree Data.RAVec.Tree.DF

hidden-modules:
    Data.RAList.Internal Data.RAList.NonEmpty.Internal
    Data.RAList.Tree.Internal TrustworthyCompat

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ral-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ral-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ral-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ral
hs-libraries:         HSral-0.2.2-GSSJQlEMbHIGAa9DjBMF29
depends:
    QuickCheck-2.15.0.1-H5XTn9FxFUBGcmB1c3fPtp
    adjunctions-4.4.3-EpJNyPLKU5W1ds1POsN27e base-4.17.2.1
    bin-0.1.4-67Qw5uFEc0m362mFsQiJhF
    boring-0.2.2-HI9VvaC9JR142cnMpyID0P deepseq-1.4.8.0
    distributive-0.6.2.1-4BGER1sRuBBJLqHRISW5MJ
    fin-0.3.2-LEDQOhFMvua4r6HyD9v5uQ
    hashable-1.4.6.0-8MG0S5dfyXU6lRGLMgbs1l
    indexed-traversable-0.1.4-1hTsLhK6E4tI5A8Ow8lBff
    semigroupoids-6.0.1-2Z3Ks6N6L6gJJh9acDP1Dt

haddock-interfaces:   /usr/share/doc/haskell-ral/html/ral.haddock
haddock-html:         /usr/share/doc/haskell-ral/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ral-0.2.2-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ral.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ral
version:              0.2.2
visibility:           public
id:                   ral-0.2.2-DlsRDk98xlaBeT85JhGsdM
key:                  ral-0.2.2-DlsRDk98xlaBeT85JhGsdM
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Random access lists
description:
    This package provides ordinary random access list, '\''RAList'\'', and also
    a length indexed variant, '\''RAVec'\''.

    The data structure allows fast cons-operation (like ordinary list) but also fast random access (like non-functional arrays).

    For @lens@ or @optics@ support see [ral-lens](https://hackage.haskell.org/package/ral-lens) and [ral-optics](https://hackage.haskell.org/package/ral-optics) packages respectively.

    === Similar packages

    These packages don'\''t provide length-indexed variants, and their '\''RAList'\'' has
    opaque structure.

    * https://hackage.haskell.org/package/ralist
    * https://hackage.haskell.org/package/random-access-list

category:             Data, Dependent Types, Singletons
abi:                  bbb0f19d3e241618213d1b41c83f08bb
exposed:              True
exposed-modules:
    Data.RAList Data.RAList.NonEmpty Data.RAList.Tree Data.RAVec
    Data.RAVec.NonEmpty Data.RAVec.Tree Data.RAVec.Tree.DF

hidden-modules:
    Data.RAList.Internal Data.RAList.NonEmpty.Internal
    Data.RAList.Tree.Internal TrustworthyCompat

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ral-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ral-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ral-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ral
hs-libraries:         HSral-0.2.2-DlsRDk98xlaBeT85JhGsdM
depends:
    QuickCheck-2.15.0.1-DNiL2W0zGk61NvlUhQ7VCE
    adjunctions-4.4.3-KBS3u5mqGZkIZ8d6jpDcid base-4.17.2.1
    bin-0.1.4-EW9Yplqz3SxC0QJdabsOSB
    boring-0.2.2-HI9VvaC9JR142cnMpyID0P deepseq-1.4.8.0
    distributive-0.6.2.1-Hv0RNQIYamu2Xta1A0P3nz
    fin-0.3.2-1JDW4flGR6GLAXtglTs1YQ
    hashable-1.4.6.0-AnOmtRToJbI9DS9f6Gdy0i
    indexed-traversable-0.1.4-9hXlgoaGrHXBpvZrKSRx7V
    semigroupoids-6.0.1-A5smyMIEEuhJFgyyaGAx41

haddock-interfaces:   /usr/share/doc/haskell-ral/html/ral.haddock
haddock-html:         /usr/share/doc/haskell-ral/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
